@@ -22,6 +22,8 @@ class InvalidSignature(NotificationValidationError):
 
 class NotificationHandler(object):
     def __init__(self, wsdl_url=WSDL_URL):
+        # TODO: should this take extra kwargs as EbaySuds does?
+        # eg make use of UserToken model
         self.client = EbaySuds(wsdl_url)
 
     def decode(self, payload_type, message):
@@ -37,11 +39,7 @@ class NotificationHandler(object):
         # copy+pasted from SoapClient.send :(
         plugins = PluginContainer(soapclient.options.plugins)
         ctx = plugins.message.received(reply=message)
-        reply.message = ctx.reply
-        if retxml:
-            result = reply.message
-        else:
-            result = soapclient.succeeded(soapclient.method.binding.input, reply.message)
+        result = soapclient.succeeded(soapclient.method.binding.input, ctx.reply)
 
         if self.validate(result):
             return result
